@@ -1,11 +1,8 @@
 from typing import Optional
 
 import pandas as pd
-from rich.console import Console
 from rich.table import Table
 
-console = Console()
-
 
 def df_to_table(
     pandas_dataframe: pd.DataFrame,
